summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Nocera <hadess@hadess.net>2021-01-11 17:50:47 +0100
committerBastien Nocera <hadess@hadess.net>2021-01-12 10:48:31 +0100
commitf3a9ba0e6ddff4b32e3938eaebd470e779aaea68 (patch)
treee2546bc9d1f16524d8d30c1e50071a6068830ff5
parent0dd6b84b3bef5809a21e6609535a1c916e02be1c (diff)
downloadlibgweather-f3a9ba0e6ddff4b32e3938eaebd470e779aaea68.tar.gz
yrno: Rename elements
They were never master/slave elements, but parent/child, as is common in XML.
-rw-r--r--libgweather/weather-metno.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libgweather/weather-metno.c b/libgweather/weather-metno.c
index fa5e012..17bc59a 100644
--- a/libgweather/weather-metno.c
+++ b/libgweather/weather-metno.c
@@ -338,10 +338,10 @@ parse_forecast_xml_new (GWeatherInfo *original_info,
to_time = date_to_time_t (val, original_info->location.tz_hint);
xmlFree (val);
- /* New API has forecast in a list of "master" elements
- with details (indicated by from==to) and "slave" elements
+ /* New API has forecast in a list of "parent" elements
+ with details (indicated by from==to) and "children" elements
that hold only precipitation and symbol. For our purpose,
- the master element is enough, except that we actually
+ the parent element is enough, except that we actually
want that symbol. So pick the symbol from the next element.
Additionally, compared to the old API the new API has one
<location> element inside each <time> element.